
# Type: double


A real number that conforms to the xsd:double specification

URI: [meta:Double](https://w3id.org/linkml/Double)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **float** |
